data.frame
or and ExpData object.
"regionGoodnessOfFit"(obj, denominator = colSums(obj), groups = rep("A", ncol(obj)))
"regionGoodnessOfFit"(obj, annoData, groups = rep("A", length(what)), what = getColnames(obj, all = FALSE), denominator = c("regions", "lanes"), verbose = getOption("verbose"))data.frame or ExpData
signature(obj = "ExpData")obj represents the results of a call to
summarizeByAnnotation or a data.frame with columns
representing samples and rows representing regions,
i.e. genes. Denominator is how we scale each column, therefore it
this must be true: length(denominator) ==
ncol(obj). Finally, groups determines how columns are aggregated
across one another, i.e. which columns are replicates. signature(obj = "data.frame")annoData is an annotation data frame. groups is
as above. what represents the columns to select
choose. denominator is either the total lane counts, or the
lane counts restricted to annoData, or a vector of length
length(groups)
ed <- ExpData(system.file(package = "Genominator", "sample.db"),
tablename = "raw")
data("yeastAnno")
names(regionGoodnessOfFit(ed, yeastAnno))
Run the code above in your browser using DataLab